IconedButton class

Constructors

IconedButton({String? text, Icon? icon, required Color color})
const

Properties

color → Color
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Icon?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited