ProgressButton class

Inheritance

Constructors

ProgressButton({Key? key, required Map<ButtonState, Widget> stateWidgets, required Map<ButtonState, Color> stateColors, ButtonState? state = ButtonState.idle, Function? onPressed, Function? onAnimationEnd, double minWidth = 200.0, double maxWidth = 400.0, double radius = 16.0, double height = 53.0, double progressIndicatorSize = 35.0, ProgressIndicator? progressIndicator, MainAxisAlignment progressIndicatorAlignment = MainAxisAlignment.spaceBetween, EdgeInsets padding = EdgeInsets.zero, List<ButtonState> minWidthStates = const <ButtonState>[ButtonState.loading], Duration animationDuration = const Duration(milliseconds: 500)})
ProgressButton.icon({required Map<ButtonState, IconedButton> iconedButtons, Function? onPressed, ButtonState? state = ButtonState.idle, Function? animationEnd, dynamic maxWidth = 170.0, dynamic minWidth = 58.0, dynamic height = 53.0, dynamic radius = 100.0, dynamic progressIndicatorSize = 35.0, double iconPadding = 4.0, TextStyle? textStyle, CircularProgressIndicator? progressIndicator, MainAxisAlignment? progressIndicatorAlignment, EdgeInsets padding = EdgeInsets.zero, List<ButtonState> minWidthStates = const <ButtonState>[ButtonState.loading]})
factory

Properties

animationDuration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxWidth → double
final
minWidth → double
final
minWidthStates → List<ButtonState>
final
onAnimationEnd → Function?
final
onPressed → Function?
final
padding → EdgeInsets
final
progressIndicator → ProgressIndicator?
final
progressIndicatorAlignment → MainAxisAlignment
final
progressIndicatorSize → double
final
radius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → ButtonState?
final
stateColors → Map<ButtonState, Color>
final
stateWidgets → Map<ButtonState, Widget>
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited